run

Function run 

pub fn run(
    config: &Config,
    db_name: Option<&str>,
    opts: GenerateOptions,
) -> Result<(), CliError>
Run the generate command.

Errors

Returns CliError if the requested database cannot be resolved, the schema files fail to parse, snapshot/diff generation fails, or writing the new migration and journal files to disk fails.