pub struct ForeignKeyDef {
pub name: String,
pub table: String,
pub columns: Vec<String>,
pub table_to: String,
pub columns_to: Vec<String>,
pub on_delete: String,
pub on_update: String,
pub pg_schema: String,
pub pg_schema_to: String,
}Fields
name: Stringtable: Stringcolumns: Vec<String>table_to: Stringcolumns_to: Vec<String>on_delete: Stringon_update: Stringpg_schema: StringPG schema
pg_schema_to: StringTrait Implementations
Sourceimpl Clone for ForeignKeyDef
impl Clone for ForeignKeyDef
Sourcefn clone(&self) -> ForeignKeyDef
fn clone(&self) -> ForeignKeyDef
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ForeignKeyDef
impl Debug for ForeignKeyDef
Sourceimpl<'de> Deserialize<'de> for ForeignKeyDef
impl<'de> Deserialize<'de> for ForeignKeyDef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ForeignKeyDef
impl JsonSchema for ForeignKeyDef
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ForeignKeyDef
impl RefUnwindSafe for ForeignKeyDef
impl Send for ForeignKeyDef
impl Sync for ForeignKeyDef
impl Unpin for ForeignKeyDef
impl UnsafeUnpin for ForeignKeyDef
impl UnwindSafe for ForeignKeyDef