pub struct SchemaDefinition {
pub dialect: Dialect,
pub casing: FieldCasing,
pub schema_name: String,
pub output_path: String,
pub enums: Vec<EnumDef>,
pub tables: Vec<TableDef>,
pub indexes: Vec<IndexDef>,
pub foreign_keys: Vec<ForeignKeyDef>,
}Fields
dialect: Dialectcasing: FieldCasingschema_name: Stringoutput_path: Stringenums: Vec<EnumDef>tables: Vec<TableDef>indexes: Vec<IndexDef>foreign_keys: Vec<ForeignKeyDef>Trait Implementations
Sourceimpl Clone for SchemaDefinition
impl Clone for SchemaDefinition
Sourcefn clone(&self) -> SchemaDefinition
fn clone(&self) -> SchemaDefinition
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SchemaDefinition
impl Debug for SchemaDefinition
Sourceimpl<'de> Deserialize<'de> for SchemaDefinition
impl<'de> Deserialize<'de> for SchemaDefinition
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SchemaDefinition
impl JsonSchema for SchemaDefinition
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SchemaDefinition
impl RefUnwindSafe for SchemaDefinition
impl Send for SchemaDefinition
impl Sync for SchemaDefinition
impl Unpin for SchemaDefinition
impl UnsafeUnpin for SchemaDefinition
impl UnwindSafe for SchemaDefinition