pub fn run( config: &Config, db_name: Option<&str>, opts: &PushOptions, ) -> Result<(), CliError>
Run the push command.
Returns CliError if the database cannot be resolved, credentials are missing or invalid, the schema files fail to parse, connecting or applying the diff to the database fails, or the user declines a destructive operation when --force is not set.
CliError
--force