run

Function run 

pub fn run(config: &Config, db_name: Option<&str>) -> Result<(), CliError>
Run the status command.

Errors

Returns CliError if the database cannot be resolved, credentials are invalid, or connecting to the database to read the migration tracking table fails.