plan_push

Function plan_push 

pub fn plan_push(
    credentials: &Credentials,
    dialect: Dialect,
    desired: &Snapshot,
    breakpoints: bool,
    filters: &SnapshotFilters,
) -> Result<PushPlan, CliError>
Plan a push by introspecting the live database and diffing against the desired snapshot.

Errors

Returns CliError if introspecting the live database fails, if applying the given snapshot filters fails, or if generating the diff SQL fails.