pub fn run( config: &Config, db_name: Option<&str>, opts: ExportOptions, ) -> Result<(), CliError>
Run the export command.
Returns CliError if the requested database cannot be resolved, the schema files cannot be read/parsed, the resolved snapshot cannot be generated, or if writing the output SQL file fails.
CliError