pub fn run( config: &Config, db_name: Option<&str>, opts: MigrateOptions, ) -> Result<(), CliError>
Run the migrate command.
Returns CliError if mutually exclusive flags are combined, the database or credentials cannot be resolved, connecting to the database fails, or applying migrations fails.
CliError