pub fn run( config: Option<&Config>, options: &NewOptions, ) -> Result<(), CliError>
Run the new command to scaffold a schema definition.
new
Returns CliError if loading or validating the JSON schema definition fails, if interactive prompts are cancelled, or if writing the generated Rust schema files fails.
CliError